@@ -28,6 +28,8 @@ parser = optparse.OptionParser(
            "options.\n")
 parser.add_option('--gui', dest="gui", default=None,
                   help="GUI toolkit: pyqt (for PyQt4) or pyside (for PySide)")
+parser.add_option('--hideconsole', dest="hide_console", action='store_true',
+                  default=False, help="Hide parent console (Windows only)")
 options, args = parser.parse_args()
 assert options.gui in (None, 'pyqt', 'pyside'), \
        "Invalid GUI toolkit option '%s'" % options.gui
@@ -63,18 +65,19 @@ print("01. Patched sys.path with %s" % DEVPATH)
 # (Note: PyQt4 is still the officially supported GUI toolkit for Spyder)
 if options.gui is None:
     try:
-        import PySide
+        import PySide  # analysis:ignore
         print("02. PySide is detected, selecting (experimental)")
         os.environ['QT_API'] = 'pyside'
     except:
         print("02. No PySide detected, using PyQt4 if available")
 else:
     print ("02. Skipping GUI toolkit detection")
-    os.environ["QT_API"] = options.gui
+    os.environ['QT_API'] = options.gui
 
-# Importing Spyder
+# Importing Spyder (among other things, this has the effect of setting the 
+# QT_API environment variable if this has not yet been done just above)
 from spyderlib import spyder
-QT_API = spyder.qt._modname
+QT_API = os.environ['QT_API']
 QT_LIB = {'pyqt': 'PyQt4', 'pyside': 'PySide'}[QT_API]
 if QT_API == 'pyqt':
     import sip
@@ -82,12 +85,14 @@ if QT_API == 'pyqt':
         QT_LIB += (" (API v%d)" % sip.getapi('QString'))
     except AttributeError:
         pass
+from spyderlib import qt
 print("03. Imported Spyder %s (Qt %s via %s %s)" % \
-    (spyder.__version__, spyder.qt.QtCore.__version__,
-     QT_LIB, spyder.qt.__version__))
+    (spyder.__version__, qt.QtCore.__version__,
+     QT_LIB, qt.__version__))
 
 # Executing Spyder
-print("0x. Enforcing parent console (Windows only)") 
-sys.argv.append("--showconsole")  # Windows only: show parent console
+if not options.hide_console:
+    print("0x. Enforcing parent console (Windows only)")
+    sys.argv.append("--showconsole")  # Windows only: show parent console
 print("04. Executing spyder.main()")
 spyder.main()
