@@ -6,10 +6,12 @@
 
 """Configuration dialog / Preferences"""
 
-import os, os.path as osp
+import os
+import os.path as osp
 
+from spyderlib.baseconfig import _
 from spyderlib.config import (get_icon, CONF, CUSTOM_COLOR_SCHEME_NAME,
-                              set_default_color_scheme, COLOR_SCHEME_NAMES, _)
+                              set_default_color_scheme, COLOR_SCHEME_NAMES)
 from spyderlib.utils.qthelpers import get_std_icon
 from spyderlib.userconfig import NoDefault
 from spyderlib.widgets.colors import ColorLayout
@@ -20,9 +22,11 @@ from spyderlib.qt.QtGui import (QWidget, QDialog, QListWidget, QListWidgetItem,
                                 QMessageBox, QLabel, QLineEdit, QSpinBox,
                                 QPushButton, QFontComboBox, QGroupBox,
                                 QComboBox, QColor, QGridLayout, QTabWidget,
-                                QRadioButton, QButtonGroup, QFileDialog,
-                                QSplitter)
-from spyderlib.qt.QtCore import Qt, QSize, SIGNAL, SLOT, QVariant
+                                QRadioButton, QButtonGroup, QSplitter,
+                                QStyleFactory, QScrollArea)
+from spyderlib.qt.QtCore import Qt, QSize, SIGNAL, SLOT, Slot
+from spyderlib.qt.compat import (to_qvariant, from_qvariant,
+                                 getexistingdirectory, getopenfilename)
 
 
 class ConfigPage(QWidget):
@@ -79,16 +83,22 @@ class ConfigPage(QWidget):
 
 
 class ConfigDialog(QDialog):
+    """Spyder configuration ('Preferences') dialog box"""
     def __init__(self, parent=None):
         QDialog.__init__(self, parent)
+        
+        # Destroying the C++ object right after closing the dialog box,
+        # otherwise it may be garbage-collected in another QThread
+        # (e.g. the editor's analysis thread in Spyder), thus leading to
+        # a segmentation fault on UNIX or an application crash on Windows
+        self.setAttribute(Qt.WA_DeleteOnClose)
 
         self.contents_widget = QListWidget()
         self.contents_widget.setMovement(QListView.Static)
-        self.contents_widget.setMinimumWidth(160 if os.name == 'nt' else 200)
         self.contents_widget.setSpacing(1)
 
         bbox = QDialogButtonBox(QDialogButtonBox.Ok|QDialogButtonBox.Apply
-                                     |QDialogButtonBox.Cancel)
+                                |QDialogButtonBox.Cancel)
         self.apply_btn = bbox.button(QDialogButtonBox.Apply)
         self.connect(bbox, SIGNAL("accepted()"), SLOT("accept()"))
         self.connect(bbox, SIGNAL("rejected()"), SLOT("reject()"))
@@ -128,10 +138,18 @@ class ConfigDialog(QDialog):
         """Set current page index"""
         self.contents_widget.setCurrentRow(index)
         
+    def get_page(self, index=None):
+        """Return page widget"""
+        if index is None:
+            widget = self.pages_widget.currentWidget()
+        else:
+            widget = self.pages_widget.widget(index)
+        return widget.widget()
+        
     def accept(self):
         """Reimplement Qt method"""
         for index in range(self.pages_widget.count()):
-            configpage = self.pages_widget.widget(index)
+            configpage = self.get_page(index)
             if not configpage.is_valid():
                 return
             configpage.apply_changes()
@@ -140,13 +158,13 @@ class ConfigDialog(QDialog):
     def button_clicked(self, button):
         if button is self.apply_btn:
             # Apply button was clicked
-            configpage = self.pages_widget.currentWidget()
+            configpage = self.get_page()
             if not configpage.is_valid():
                 return
             configpage.apply_changes()
             
     def current_page_changed(self, index):
-        widget = self.pages_widget.widget(index)
+        widget = self.get_page(index)
         self.apply_btn.setVisible(widget.apply_callback is not None)
         self.apply_btn.setEnabled(widget.is_modified)
         
@@ -157,7 +175,10 @@ class ConfigDialog(QDialog):
                      self.contents_widget.setCurrentRow(row))
         self.connect(widget, SIGNAL("apply_button_enabled(bool)"),
                      self.apply_btn.setEnabled)
-        self.pages_widget.addWidget(widget)
+        scrollarea = QScrollArea(self)
+        scrollarea.setWidgetResizable(True)
+        scrollarea.setWidget(widget)
+        self.pages_widget.addWidget(scrollarea)
         item = QListWidgetItem(self.contents_widget)
         item.setIcon(widget.get_icon())
         item.setText(widget.get_name())
@@ -218,74 +239,69 @@ class SpyderConfigPage(ConfigPage):
         """Load settings from configuration file"""
         for checkbox, (option, default) in self.checkboxes.items():
             checkbox.setChecked(self.get_option(option, default))
-            checkbox.setProperty("option", QVariant(option))
             self.connect(checkbox, SIGNAL("clicked(bool)"),
-                         lambda checked: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
         for radiobutton, (option, default) in self.radiobuttons.items():
             radiobutton.setChecked(self.get_option(option, default))
-            radiobutton.setProperty("option", QVariant(option))
             self.connect(radiobutton, SIGNAL("toggled(bool)"),
-                         lambda checked: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
         for lineedit, (option, default) in self.lineedits.items():
             lineedit.setText(self.get_option(option, default))
-            lineedit.setProperty("option", QVariant(option))
             self.connect(lineedit, SIGNAL("textChanged(QString)"),
-                         lambda text: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
         for spinbox, (option, default) in self.spinboxes.items():
             spinbox.setValue(self.get_option(option, default))
-            spinbox.setProperty("option", QVariant(option))
             self.connect(spinbox, SIGNAL('valueChanged(int)'),
-                         lambda value: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
         for combobox, (option, default) in self.comboboxes.items():
             value = self.get_option(option, default)
             for index in range(combobox.count()):
-                if unicode(combobox.itemData(index).toString()
-                           ) == unicode(value):
+                data = from_qvariant(combobox.itemData(index), unicode)
+                # For PyQt API v2, it is necessary to convert `data` to 
+                # unicode in case the original type was not a string, like an 
+                # integer for example (see spyderlib.qt.compat.from_qvariant):
+                if unicode(data) == unicode(value):
                     break
             combobox.setCurrentIndex(index)
-            combobox.setProperty("option", QVariant(option))
             self.connect(combobox, SIGNAL('currentIndexChanged(int)'),
-                         lambda index: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
         for (fontbox, sizebox), option in self.fontboxes.items():
             font = self.get_font(option)
             fontbox.setCurrentFont(font)
             sizebox.setValue(font.pointSize())
             if option is None:
-                property = QVariant('plugin_font')
+                property = 'plugin_font'
             else:
-                property = QVariant(option)
-            fontbox.setProperty("option", property)
+                property = option
             self.connect(fontbox, SIGNAL('currentIndexChanged(int)'),
-                         lambda index: self.has_been_modified())
-            sizebox.setProperty("option", property)
+                         lambda _foo, opt=property: self.has_been_modified(opt))
             self.connect(sizebox, SIGNAL('valueChanged(int)'),
-                         lambda value: self.has_been_modified())
+                         lambda _foo, opt=property: self.has_been_modified(opt))
         for clayout, (option, default) in self.coloredits.items():
-            property = QVariant(option)
+            property = to_qvariant(option)
             edit = clayout.lineedit
             btn = clayout.colorbtn
             edit.setText(self.get_option(option, default))
-            edit.setProperty("option", property)
-            btn.setProperty("option", property)
-            self.connect(btn, SIGNAL('clicked()'), self.has_been_modified)
+            self.connect(btn, SIGNAL('clicked()'),
+                         lambda opt=option: self.has_been_modified(opt))
             self.connect(edit, SIGNAL("textChanged(QString)"),
-                         lambda text: self.has_been_modified())
-        for (clayout, cb_bold, cb_italic), (option, default) in self.scedits.items():
+                         lambda _foo, opt=option: self.has_been_modified(opt))
+        for (clayout, cb_bold, cb_italic
+             ), (option, default) in self.scedits.items():
             edit = clayout.lineedit
             btn = clayout.colorbtn
             color, bold, italic = self.get_option(option, default)
             edit.setText(color)
             cb_bold.setChecked(bold)
             cb_italic.setChecked(italic)
-            for _w in (edit, btn, cb_bold, cb_italic):
-                _w.setProperty("option", QVariant(option))
-            self.connect(btn, SIGNAL('clicked()'), self.has_been_modified)
+            self.connect(btn, SIGNAL('clicked()'),
+                         lambda opt=option: self.has_been_modified(opt))
             self.connect(edit, SIGNAL("textChanged(QString)"),
-                         lambda text: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
             self.connect(cb_bold, SIGNAL("clicked(bool)"),
-                         lambda checked: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
             self.connect(cb_italic, SIGNAL("clicked(bool)"),
-                         lambda checked: self.has_been_modified())
+                         lambda _foo, opt=option: self.has_been_modified(opt))
     
     def save_to_conf(self):
         """Save settings to configuration file"""
@@ -299,7 +315,7 @@ class SpyderConfigPage(ConfigPage):
             self.set_option(option, spinbox.value())
         for combobox, (option, _default) in self.comboboxes.items():
             data = combobox.itemData(combobox.currentIndex())
-            self.set_option(option, unicode(data.toString()))
+            self.set_option(option, from_qvariant(data, unicode))
         for (fontbox, sizebox), option in self.fontboxes.items():
             font = fontbox.currentFont()
             font.setPointSize(sizebox.value())
@@ -312,8 +328,8 @@ class SpyderConfigPage(ConfigPage):
             italic = cb_italic.isChecked()
             self.set_option(option, (color, bold, italic))
     
-    def has_been_modified(self):
-        option = unicode(self.sender().property("option").toString())
+    @Slot(str)
+    def has_been_modified(self, option):
         self.set_modified(True)
         self.changed_options.add(option)
     
@@ -402,8 +418,8 @@ class SpyderConfigPage(ConfigPage):
         if not osp.isdir(basedir):
             basedir = os.getcwdu()
         title = _("Select directory")
-        directory = QFileDialog.getExistingDirectory(self, title, basedir)
-        if not directory.isEmpty():
+        directory = getexistingdirectory(self, title, basedir)
+        if directory:
             edit.setText(directory)
     
     def create_browsefile(self, text, option, default=NoDefault, tip=None,
@@ -435,7 +451,7 @@ class SpyderConfigPage(ConfigPage):
         if filters is None:
             filters = _("All files (*)")
         title = _("Select file")
-        filename = QFileDialog.getOpenFileName(self, title, basedir, filters)
+        filename, _selfilter = getopenfilename(self, title, basedir, filters)
         if filename:
             edit.setText(filename)
     
@@ -524,7 +540,7 @@ class SpyderConfigPage(ConfigPage):
         if tip is not None:
             combobox.setToolTip(tip)
         for name, key in choices:
-            combobox.addItem(name, QVariant(key))
+            combobox.addItem(name, to_qvariant(key))
         self.comboboxes[combobox] = (option, default)
         layout = QHBoxLayout()
         for subwidget in (label, combobox):
@@ -561,8 +577,8 @@ class SpyderConfigPage(ConfigPage):
     def create_button(self, text, callback):
         btn = QPushButton(text)
         self.connect(btn, SIGNAL('clicked()'), callback)
-        btn.setProperty("option", QVariant(""))
-        self.connect(btn, SIGNAL('clicked()'), self.has_been_modified)
+        self.connect(btn, SIGNAL('clicked()'),
+                     lambda opt='': self.has_been_modified(opt))
         return btn
     
     def create_tab(self, *widgets):
@@ -602,6 +618,11 @@ class MainConfigPage(GeneralConfigPage):
     
     def setup_page(self):
         interface_group = QGroupBox(_("Interface"))
+        styles = [str(txt) for txt in QStyleFactory.keys()]
+        choices = zip(styles, [style.lower() for style in styles])
+        style_combo = self.create_combobox(_('Qt windows style'), choices,
+                                           'windows_style',
+                                           default=self.main.default_style)
         newcb = self.create_checkbox
         vertdock_box = newcb(_("Vertical dockwidget title bars"),
                              'vertical_dockwidget_titlebars')
@@ -621,6 +642,7 @@ class MainConfigPage(GeneralConfigPage):
         margins_layout.addWidget(margin_spin)
         
         interface_layout = QVBoxLayout()
+        interface_layout.addWidget(style_combo)
         interface_layout.addWidget(vertdock_box)
         interface_layout.addWidget(verttabs_box)
         interface_layout.addWidget(animated_box)
@@ -693,8 +715,7 @@ class ColorSchemeConfigPage(GeneralConfigPage):
             cs_group.setLayout(cs_layout)
             if tabname in COLOR_SCHEME_NAMES:
                 def_btn = self.create_button(_("Reset to default values"),
-                                             self.reset_to_default)
-                def_btn.setProperty("name", QVariant(tabname))
+                                         lambda: self.reset_to_default(tabname))
                 tabs.addTab(self.create_tab(cs_group, def_btn), tabname)
             else:
                 tabs.addTab(self.create_tab(cs_group), tabname)
@@ -703,8 +724,8 @@ class ColorSchemeConfigPage(GeneralConfigPage):
         vlayout.addWidget(tabs)
         self.setLayout(vlayout)
         
-    def reset_to_default(self):
-        name = unicode(self.sender().property("name").toString())
+    @Slot(str)
+    def reset_to_default(self, name):
         set_default_color_scheme(name, replace=True)
         self.load_from_conf()
             
