@@ -16,12 +16,10 @@ from spyderlib.qt.QtGui import (QVBoxLayout, QFontDialog, QInputDialog,
 from spyderlib.qt.QtCore import SIGNAL
 from spyderlib.qt.compat import getopenfilename
 
-import os, sys
+import os
+import sys
 import os.path as osp
 
-# For debugging purpose:
-STDOUT = sys.stdout
-
 
 # Local imports
 from spyderlib.baseconfig import _
@@ -189,6 +187,15 @@ class Console(SpyderPluginWidget):
         self.connect(self, SIGNAL('focus_changed()'),
                      self.main.plugin_focus_changed)
         self.main.add_dockwidget(self)
+        # Connecting the following signal once the dockwidget has been created:
+        self.connect(self.shell, SIGNAL('traceback_available()'),
+                     self.traceback_available)
+    
+    def traceback_available(self):
+        """Traceback is available in the internal console: showing the 
+        internal console automatically to warn the user"""
+        self.dockwidget.show()
+        self.dockwidget.raise_()
         
     #------ Public API ---------------------------------------------------------
     def quit(self):
