@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+﻿# -*- coding: utf-8 -*-
 #
 # Copyright © 2009-2010 Pierre Raybaut
 # Licensed under the terms of the MIT License
@@ -113,6 +113,7 @@ class EditorConfigPage(PluginConfigPage):
                                              min_=100, max_=1000000, step=100)
         self.connect(occurence_box, SIGNAL("toggled(bool)"),
                      occurence_spin.setEnabled)
+        occurence_spin.setEnabled(self.get_option('occurence_highlighting'))
         occurence_layout = QHBoxLayout()
         occurence_layout.addWidget(occurence_box)
         occurence_layout.addWidget(occurence_spin)
@@ -633,7 +634,7 @@ class Editor(SpyderPluginWidget):
                                name="Debug", default="Ctrl+F5")
         configure_action = create_action(self,
                 _("&Configure..."), icon='configure.png',
-                tip=_("Edit run configurations"),
+                tip=_("Edit run configurations"), menurole=QAction.NoRole,
                 triggered=self.edit_run_configurations)
         self.register_shortcut(configure_action, context="Editor",
                                name="Configure", default="F6")
@@ -991,14 +992,14 @@ class Editor(SpyderPluginWidget):
         self.connect(editorstack, SIGNAL("update_plugin_title()"),
                      lambda: self.emit(SIGNAL("update_plugin_title()")))
 
-        self.connect(self, SIGNAL("editor_focus_changed()"),
+        self.connect(editorstack, SIGNAL("editor_focus_changed()"),
                      self.save_focus_editorstack)
-        self.connect(self, SIGNAL('editor_focus_changed()'),
+        self.connect(editorstack, SIGNAL('editor_focus_changed()'),
                      self.main.plugin_focus_changed)
         
-        self.connect(editorstack, SIGNAL('close_file(int,int)'),
+        self.connect(editorstack, SIGNAL('close_file(long,long)'),
                      self.close_file_in_all_editorstacks)
-        self.connect(editorstack, SIGNAL('file_saved(int,int)'),
+        self.connect(editorstack, SIGNAL('file_saved(long,long)'),
                      self.file_saved_in_editorstack)
         
         self.connect(editorstack, SIGNAL("create_new_window()"),
@@ -1047,6 +1048,8 @@ class Editor(SpyderPluginWidget):
         
     def clone_editorstack(self, editorstack):
         editorstack.clone_from(self.editorstacks[0])
+        for finfo in editorstack.data:
+            self.register_widget_shortcuts("Editor", finfo.editor)
         
     @Slot(int, int)
     def close_file_in_all_editorstacks(self, editorstack_id, index):
@@ -1339,9 +1342,13 @@ class Editor(SpyderPluginWidget):
         if encoding_match:
             enc = encoding_match.group(1)
         # Initialize template variables
-        username = os.environ.get('USERNAME', None) # Windows, Linux
+        # Windows
+        username = encoding.to_unicode_from_fs(os.environ.get('USERNAME',
+                                                              ''))
+        # Linux, Mac OS X
         if not username:
-            username = os.environ.get('USER', '-')  # Mac OS
+            username = encoding.to_unicode_from_fs(os.environ.get('USER',
+                                                                  '-'))
         VARS = {
             'date':time.ctime(),
             'username':username,
@@ -1471,7 +1478,7 @@ class Editor(SpyderPluginWidget):
             self.dockwidget.raise_()
         
         def _convert(fname):
-            fname = osp.abspath(encoding.to_unicode(fname))
+            fname = osp.abspath(encoding.to_unicode_from_fs(fname))
             if os.name == 'nt' and len(fname) >= 2 and fname[1] == ':':
                 fname = fname[0].upper()+fname[1:]
             return fname
@@ -1663,7 +1670,18 @@ class Editor(SpyderPluginWidget):
         """Run winpdb to debug current file"""
         if self.save():
             fname = self.get_current_filename()
-            programs.run_program(WINPDB_PATH, [fname])
+            runconf = get_run_configuration(fname)
+            if runconf is None:
+                args = []
+                wdir = None
+            else:
+                args = runconf.get_arguments().split()
+                wdir = runconf.get_working_directory()
+                # Handle the case where wdir comes back as an empty string
+                # when the working directory dialog checkbox is unchecked.
+                if not wdir:
+                    wdir = None
+            programs.run_program(WINPDB_PATH, [fname]+args, wdir)
         
     def toggle_eol_chars(self, os_name):
         editor = self.get_current_editor()
@@ -1802,7 +1820,7 @@ class Editor(SpyderPluginWidget):
         if self.configdialog_size is not None:
             dialog.resize(self.configdialog_size)
         if dialog.exec_():
-            self.configdialog_size = dialog.win_size
+            self.configdialog_size = dialog.get_window_size()
             fname = dialog.file_to_run
             if fname is not None:
                 self.load(fname)
@@ -1823,7 +1841,7 @@ class Editor(SpyderPluginWidget):
                     dialog.resize(self.configdialog_size)
                 if not dialog.exec_():
                     return
-                self.configdialog_size = dialog.win_size
+                self.configdialog_size = dialog.get_window_size()
                 runconf = dialog.get_configuration()
                 
             wdir = runconf.get_working_directory()
