@@ -21,6 +21,7 @@ import sys
 import os
 import os.path as osp
 import imp
+import re
 
 # Local imports
 from spyderlib.baseconfig import _, SCIENTIFIC_STARTUP
@@ -100,8 +101,8 @@ class ExternalConsoleConfigPage(PluginConfigPage):
                             'light_background')
         ipybg_box = newcb(_("Set the appropriate IPython color option"),
                           'ipython_set_color')
-        ipython_is_installed = programs.is_module_installed('IPython', '0.1')
-        ipybg_box.setEnabled(ipython_is_installed)
+        is_ipython_010 = programs.is_module_installed('IPython', '0.10')
+        ipybg_box.setEnabled(is_ipython_010)
         bg_layout = QVBoxLayout()
         bg_layout.addWidget(bg_label)
         bg_layout.addWidget(lightbg_box)
@@ -198,17 +199,24 @@ class ExternalConsoleConfigPage(PluginConfigPage):
                               'open_python_at_startup')
         ipystartup_box = newcb(_("Open an IPython interpreter at startup"),
                                'open_ipython_at_startup')
-        is_ipython_010 = programs.is_module_installed('IPython', '0.10')
         ipystartup_box.setEnabled(is_ipython_010)
         if not is_ipython_010:
             ipystartup_box.setToolTip(
                         _("This option is not available for IPython\n"
                           "versions which are not fully supported\n"
                           "through Spyder's console (i.e. IPython v0.11+)."))
+        ipykstartup_box = newcb(_("Start an IPython kernel at startup"),
+                                'start_ipython_kernel_at_startup')
+        is_ipython_012p = programs.is_module_installed('IPython', '>=0.12')
+        ipykstartup_box.setEnabled(is_ipython_012p)
+        if not is_ipython_012p:
+            ipykstartup_box.setToolTip(_("This option is not available for "
+                                        "IPython versions prior to v0.12."))
         
         startup_layout = QVBoxLayout()
         startup_layout.addWidget(pystartup_box)
         startup_layout.addWidget(ipystartup_box)
+        startup_layout.addWidget(ipykstartup_box)
         startup_group.setLayout(startup_layout)
         
         # PYTHONSTARTUP replacement
@@ -301,36 +309,37 @@ enabled and that it has no effect in IPython."""))
         qt_group.setEnabled(has_pyqt4 or has_pyside)
         
         # PyQt Group
-        pyqt_group = QGroupBox(_("PyQt"))
-        pyqt_setapi_box = self.create_combobox(
+        if has_pyqt4:
+            pyqt_group = QGroupBox(_("PyQt"))
+            setapi_box = self.create_combobox(
                 _("API selection for QString and QVariant objects:"),
                 ((_("Default API"), 0), (_("API #1"), 1), (_("API #2"), 2)),
                 'pyqt/api_version', default=0, tip=_(
 """PyQt API #1 is the default API for Python 2. PyQt API #2 is the default 
 API for Python 3 and is compatible with PySide.
 Note that switching to API #2 may require to enable the Matplotlib patch."""))
-        pyqt_ignore_api_box = newcb(_("Ignore API change errors (sip.setapi)"),
-                                    'pyqt/ignore_sip_setapi_errors', tip=_(
+            ignore_api_box = newcb(_("Ignore API change errors (sip.setapi)"),
+                                     'pyqt/ignore_sip_setapi_errors', tip=_(
 """Enabling this option will ignore errors when changing PyQt API.
 As PyQt does not support dynamic API changes, it is strongly recommended
 to use this feature wisely, e.g. for debugging purpose."""))
-        try:
-            from sip import setapi #analysis:ignore
-        except ImportError:
-            pyqt_setapi_box.setDisabled(True)
-            pyqt_ignore_api_box.setDisabled(True)
-        
-        pyqt_layout = QVBoxLayout()
-        pyqt_layout.addWidget(pyqt_setapi_box)
-        pyqt_layout.addWidget(pyqt_ignore_api_box)
-        pyqt_group.setLayout(pyqt_layout)
-        pyqt_group.setVisible(has_pyqt4)
-        qt_layout.addWidget(pyqt_group)
+            try:
+                from sip import setapi #analysis:ignore
+            except ImportError:
+                setapi_box.setDisabled(True)
+                ignore_api_box.setDisabled(True)
+            
+            pyqt_layout = QVBoxLayout()
+            pyqt_layout.addWidget(setapi_box)
+            pyqt_layout.addWidget(ignore_api_box)
+            pyqt_group.setLayout(pyqt_layout)
+            qt_layout.addWidget(pyqt_group)
         
         # IPython Group
         ipython_group = QGroupBox(
                             _("IPython interpreter command line options"))
         ipython_layout = QVBoxLayout()
+        ipython_is_installed = programs.is_module_installed('IPython', '0.1')
         if ipython_is_installed:
             if programs.is_module_installed('IPython', '0.12'):
                 ipython_edit_012 = self.create_lineedit("IPython >=v0.12",
@@ -438,7 +447,6 @@ class ExternalConsole(SpyderPluginWidget):
         self.variableexplorer = None # Variable explorer plugin
         
         self.ipython_shell_count = 0
-        self.ipython_kernel_count = 0
         self.python_count = 0
         self.terminal_count = 0
 
@@ -528,7 +536,14 @@ class ExternalConsole(SpyderPluginWidget):
         self.icons.insert(index_to, icons)
         self.emit(SIGNAL('update_plugin_title()'))
 
+    def get_shell_index_from_id(self, shell_id):
+        """Return shellwidget index from id"""
+        for index, shell in enumerate(self.shellwidgets):
+            if id(shell) == shell_id:
+                return index
+        
     def close_console(self, index=None):
+        """Close console tab from index or widget (or close current tab)"""
         if not self.tabwidget.count():
             return
         if index is None:
@@ -552,7 +567,11 @@ class ExternalConsole(SpyderPluginWidget):
         for index in [current_index]+range(self.tabwidget.count()):
             shellwidget = self.tabwidget.widget(index)
             if isinstance(shellwidget, pythonshell.ExternalPythonShell):
-                if not interpreter_only or shellwidget.is_interpreter:
+                if interpreter_only and not shellwidget.is_interpreter:
+                    continue
+                elif not shellwidget.is_running():
+                    continue
+                else:
                     self.tabwidget.setCurrentIndex(index)
                     return shellwidget
                 
@@ -579,31 +598,35 @@ class ExternalConsole(SpyderPluginWidget):
         
     def run_script_in_current_shell(self, filename, wdir, args, debug):
         """Run script in current shell, if any"""
-        shellwidget = self.__find_python_shell(interpreter_only=True)
-        if shellwidget is not None and shellwidget.is_running():
-            line = "%s(r'%s'" % ('debugfile' if debug else 'runfile',
-                                 unicode(filename))
-            norm = lambda text: remove_trailing_single_backslash(unicode(text))
-            if args:
-                line += ", args=r'%s'" % norm(args)
-            if wdir:
-                line += ", wdir=r'%s'" % norm(wdir)
-            line += ")"
-            shellwidget.shell.execute_lines(line)
-            shellwidget.shell.setFocus()
+        line = "%s(r'%s'" % ('debugfile' if debug else 'runfile',
+                             unicode(filename))
+        norm = lambda text: remove_trailing_single_backslash(unicode(text))
+        if args:
+            line += ", args=r'%s'" % norm(args)
+        if wdir:
+            line += ", wdir=r'%s'" % norm(wdir)
+        line += ")"
+        self.execute_python_code(line, interpreter_only=True)
             
     def set_current_shell_working_directory(self, directory):
         """Set current shell working directory"""
         shellwidget = self.__find_python_shell()
-        if shellwidget is not None and shellwidget.is_running():
+        if shellwidget is not None:
             shellwidget.shell.set_cwd(unicode(directory))
         
-    def execute_python_code(self, lines):
+    def execute_python_code(self, lines, interpreter_only=False):
         """Execute Python code in an already opened Python interpreter"""
-        shellwidget = self.__find_python_shell()
+        shellwidget = self.__find_python_shell(
+                                        interpreter_only=interpreter_only)
         if shellwidget is not None:
-            shellwidget.shell.execute_lines(unicode(lines))
-            shellwidget.shell.setFocus()
+            if shellwidget.is_ipython_kernel:
+                #  IPython plugin
+                ipython_widget = self.main.get_ipython_widget(id(shellwidget))
+                ipython_widget.execute(unicode(lines))
+                ipython_widget.setFocus()
+            else:
+                shellwidget.shell.execute_lines(unicode(lines))
+                shellwidget.shell.setFocus()
             
     def pdb_has_stopped(self, fname, lineno, shell):
         """Python debugger has just stopped at frame (fname, lineno)"""
@@ -777,17 +800,13 @@ class ExternalConsole(SpyderPluginWidget):
                     tab_icon1 = get_icon('ipython.png')
                     tab_icon2 = get_icon('ipython_t.png')
                 elif ipython_kernel:
-                    self.ipython_kernel_count += 1
-                    tab_name = "IPyKernel %d" % self.ipython_kernel_count
+                    tab_name = "IPyKernel"
                     tab_icon1 = get_icon('ipython.png')
                     tab_icon2 = get_icon('ipython_t.png')
-                    kernel_name = "IPK%d" % self.ipython_kernel_count
                     self.connect(shellwidget,
                                  SIGNAL('create_ipython_frontend(QString)'),
-                                 lambda args:
-                                 self.main.new_ipython_frontend(
-                                 args, kernel_widget=shellwidget,
-                                 kernel_name=kernel_name))
+                                 lambda cf: self.create_ipython_frontend(
+                                         cf, kernel_widget_id=id(shellwidget)))
                 else:
                     self.python_count += 1
                     tab_name = "Python %d" % self.python_count
@@ -832,34 +851,44 @@ class ExternalConsole(SpyderPluginWidget):
         shellwidget.start_shell()
         shellwidget.shell.setFocus()
         
+    def create_ipython_frontend(self, connection_file, kernel_widget_id):
+        """Create a new IPython frontend connected to a kernel just started"""
+        index = self.get_shell_index_from_id(kernel_widget_id)
+        match = re.match('^kernel-(\d+).json', connection_file)
+        if match is not None:  # should not fail, but we never know...
+            text = unicode(self.tabwidget.tabText(index))
+            name = "%s (%s)" % (text, match.groups()[0])
+            self.tabwidget.setTabText(index, name)
+        self.main.new_ipython_frontend(connection_file, kernel_widget_id)
+        
     def open_file_in_spyder(self, fname, lineno):
         """Open file in Spyder's editor from remote process"""
         self.main.editor.activateWindow()
         self.main.editor.raise_()
         self.main.editor.load(fname, lineno)
         
-    #------ Private API --------------------------------------------------------
+    #------ Private API -------------------------------------------------------
     def process_started(self, shell_id):
-        for index, shell in enumerate(self.shellwidgets):
-            if id(shell) == shell_id:
-                icon, _icon = self.icons[index]
-                self.tabwidget.setTabIcon(index, icon)
-                if self.inspector is not None:
-                    self.inspector.set_shell(shell.shell)
-                if self.variableexplorer is not None:
-                    self.variableexplorer.add_shellwidget(shell)
+        index = self.get_shell_index_from_id(shell_id)
+        shell = self.shellwidgets[index]
+        icon, _icon = self.icons[index]
+        self.tabwidget.setTabIcon(index, icon)
+        if self.inspector is not None:
+            self.inspector.set_shell(shell.shell)
+        if self.variableexplorer is not None:
+            self.variableexplorer.add_shellwidget(shell)
         
     def process_finished(self, shell_id):
-        for index, shell in enumerate(self.shellwidgets):
-            if id(shell) == shell_id:
-                _icon, icon = self.icons[index]
-                self.tabwidget.setTabIcon(index, icon)
-                if self.inspector is not None:
-                    self.inspector.shell_terminated(shell.shell)
+        index = self.get_shell_index_from_id(shell_id)
+        shell = self.shellwidgets[index]
+        _icon, icon = self.icons[index]
+        self.tabwidget.setTabIcon(index, icon)
+        if self.inspector is not None:
+            self.inspector.shell_terminated(shell.shell)
         if self.variableexplorer is not None:
             self.variableexplorer.remove_shellwidget(shell_id)
         
-    #------ SpyderPluginWidget API ---------------------------------------------    
+    #------ SpyderPluginWidget API --------------------------------------------
     def get_plugin_title(self):
         """Return widget title"""
         title = _('Console')
@@ -907,7 +936,7 @@ class ExternalConsole(SpyderPluginWidget):
         ipython_kernel_action = create_action(self,
                             _("Start a new IPython kernel"), None,
                             'ipython.png', triggered=self.start_ipython_kernel)
-        if programs.is_module_installed('IPython', '0.12'):
+        if programs.is_module_installed('IPython', '>=0.12'):
             self.menu_actions.insert(1, ipython_kernel_action)
             interact_menu_actions.append(ipython_kernel_action)
         
@@ -916,7 +945,7 @@ class ExternalConsole(SpyderPluginWidget):
                             'ipython.png',
                             _("Open an IPython interpreter"),
                             triggered=self.open_ipython)
-        if programs.is_module_installed('IPython', '0.1'):
+        if programs.is_module_installed('IPython', '>=0.10'):
             self.menu_actions.insert(1, ipython_action)
             interact_menu_actions.append(ipython_action)
         
@@ -1061,6 +1090,8 @@ class ExternalConsole(SpyderPluginWidget):
                 self.set_option('open_python_at_startup', True)
         if self.get_option('open_python_at_startup', True):
             self.open_interpreter()
+        if self.get_option('start_ipython_kernel_at_startup', False):
+            self.start_ipython_kernel()
             
     def open_interpreter(self, wdir=None):
         """Open interpreter"""
