@@ -10,12 +10,20 @@ Spyder, the Scientific PYthon Development EnviRonment
 
 Developped and maintained by Pierre Raybaut
 
-Copyright © 2009-2011 Pierre Raybaut
+Copyright © 2009-2012 Pierre Raybaut
 Licensed under the terms of the MIT License
 (see spyderlib/__init__.py for details)
 """
 
 import os
+import sys
+import os.path as osp
+import platform
+import re
+
+# Keeping a reference to the original sys.exit before patching it
+ORIGINAL_SYS_EXIT = sys.exit
+
 try:
     # Test if IPython v0.11+ is installed
     import IPython
@@ -28,21 +36,12 @@ try:
         from IPython.external import qt #analysis:ignore
 except ImportError:
     pass
-from spyderlib import qt #analysis:ignore
 
 # Check requirements
 from spyderlib import requirements
 requirements.check_path()
 requirements.check_qt()
 
-import sys
-import os.path as osp
-import platform
-import re
-
-# Keeping a reference to the original sys.exit before patching it
-ORIGINAL_SYS_EXIT = sys.exit
-
 # Windows platforms only: support for hiding the attached console window
 set_attached_console_visible = None
 is_attached_console_visible = None
@@ -68,7 +67,7 @@ if os.name == 'nt':
 # Workaround: importing rope.base.project here, otherwise this module can't
 # be imported if Spyder was executed from another folder than spyderlib
 try:
-    import rope.base.project #@UnusedImport
+    import rope.base.project  # analysis:ignore
 except ImportError:
     pass
 
@@ -79,6 +78,11 @@ from spyderlib.qt.QtGui import (QApplication, QMainWindow, QSplashScreen,
 from spyderlib.qt.QtCore import SIGNAL, QPoint, Qt, QSize, QByteArray, QUrl
 from spyderlib.qt.compat import (from_qvariant, getopenfilename,
                                  getsavefilename)
+# Avoid a "Cannot mix incompatible Qt library" error on Windows platforms 
+# when PySide is selected by the QT_API environment variable and when PyQt4 
+# is also installed (or any other Qt-based application prepending a directory
+# containing incompatible Qt DLLs versions in PATH):
+from spyderlib.qt import QtSvg  # analysis:ignore
 
 # Local imports
 from spyderlib import __version__, __project_url__, __forum_url__
@@ -86,7 +90,7 @@ from spyderlib.utils import encoding
 try:
     from spyderlib.utils.environ import WinUserEnvDialog
 except ImportError:
-    WinUserEnvDialog = None
+    WinUserEnvDialog = None  # analysis:ignore
 from spyderlib.widgets.pathmanager import PathManager
 from spyderlib.plugins.configdialog import (ConfigDialog, MainConfigPage,
                                             ColorSchemeConfigPage)
@@ -101,7 +105,7 @@ try:
     from spyderlib.plugins.onlinehelp import OnlineHelp
 except ImportError:
     # Qt < v4.4
-    OnlineHelp = None
+    OnlineHelp = None  # analysis:ignore
 from spyderlib.plugins.explorer import Explorer
 from spyderlib.plugins.externalconsole import ExternalConsole
 from spyderlib.plugins.variableexplorer import VariableExplorer
@@ -123,7 +127,7 @@ from spyderlib.utils.programs import (run_python_script, is_module_installed,
                                       start_file, run_python_script_in_terminal)
 from spyderlib.utils.iofuncs import load_session, save_session, reset_session
 from spyderlib.userconfig import NoDefault, NoOptionError
-from spyderlib.utils.module_completion import getRootModules, MODULES_PATH
+from spyderlib.utils.module_completion import modules_db
 
 
 TEMP_SESSION_PATH = get_conf_path('.temp.session.tar')
@@ -150,6 +154,36 @@ def get_python_doc_path():
         return file_uri(python_doc)
 
 
+#==============================================================================
+# Spyder's main window widgets utilities
+#==============================================================================
+def get_focus_python_shell():
+    """Extract and return Python shell from widget
+    Return None if *widget* is not a Python shell (e.g. IPython kernel)"""
+    widget = QApplication.focusWidget()
+    from spyderlib.widgets.shell import PythonShellWidget
+    from spyderlib.widgets.externalshell.pythonshell import ExternalPythonShell
+    if isinstance(widget, PythonShellWidget):
+        return widget
+    elif isinstance(widget, ExternalPythonShell):
+        return widget.shell
+
+def get_focus_widget_properties():
+    """Get properties of focus widget
+    Returns tuple (widget, properties) where properties is a tuple of
+    booleans: (is_console, not_readonly, readwrite_editor)"""
+    widget = QApplication.focusWidget()
+    from spyderlib.widgets.shell import ShellBaseWidget
+    from spyderlib.widgets.editor import TextEditBaseWidget
+    textedit_properties = None
+    if isinstance(widget, (ShellBaseWidget, TextEditBaseWidget)):
+        console = isinstance(widget, ShellBaseWidget)
+        not_readonly = not widget.isReadOnly()
+        readwrite_editor = not_readonly and not console
+        textedit_properties = (console, not_readonly, readwrite_editor)
+    return widget, textedit_properties
+
+
 #TODO: Improve the stylesheet below for separator handles to be visible
 #      (in Qt, these handles are by default not visible on Windows!)
 STYLESHEET="""
@@ -530,10 +564,11 @@ class MainWindow(QMainWindow):
             self.register_shortcut(prefs_action, "_", "Preferences",
                                    "Ctrl+Alt+Shift+P")
             spyder_path_action = create_action(self,
-                                        _("PYTHONPATH manager"),
-                                        None, 'pythonpath_mgr.png',
-                                        triggered=self.path_manager_callback,
-                                        tip=_("Open Spyder path manager"))
+                                    _("PYTHONPATH manager"),
+                                    None, 'pythonpath_mgr.png',
+                                    triggered=self.path_manager_callback,
+                                    tip=_("Open Spyder path manager"),
+                                    menurole=QAction.ApplicationSpecificRole)
             update_modules_action = create_action(self,
                                         _("Update module names list"),
                                         None, 'reload.png',
@@ -542,7 +577,10 @@ class MainWindow(QMainWindow):
                                               "the modules available in your "
                                               "PYTHONPATH"))
             self.tools_menu_actions = [prefs_action, spyder_path_action]
-            self.tools_menu_actions += [update_modules_action, None]
+            if osp.isfile(get_conf_path('db/rootmodules')):
+                self.tools_menu_actions += [update_modules_action, None]
+            else:
+                self.tools_menu_actions += [None]
             self.main_toolbar_actions += [prefs_action, spyder_path_action]
             if WinUserEnvDialog is not None:
                 winenv_action = create_action(self,
@@ -1080,54 +1118,53 @@ class MainWindow(QMainWindow):
         self.save_current_window_settings('layout_%d/' % index,
                                           section='quick_layouts')
 
-    def __focus_shell(self):
-        """Return Python shell widget which has focus, if any"""
-        widget = QApplication.focusWidget()
-        from spyderlib.widgets.shell import PythonShellWidget
-        from spyderlib.widgets.externalshell.pythonshell import ExternalPythonShell
-        if isinstance(widget, PythonShellWidget):
-            return widget
-        elif isinstance(widget, ExternalPythonShell):
-            return widget.shell
-        
     def plugin_focus_changed(self):
         """Focus has changed from one plugin to another"""
+        if self.light:
+            #  There is currently no point doing the following in light mode
+            return
         self.update_edit_menu()
         self.update_search_menu()
-        shell = self.__focus_shell()
-        if shell is not None and self.inspector is not None:
-            self.inspector.set_shell(shell)
+        shell = get_focus_python_shell()
+        if shell is not None:
+            # A Python shell widget has focus
+            if self.inspector is not None:
+                #  The object inspector may be disabled in .spyder.ini
+                self.inspector.set_shell(shell)
             from spyderlib.widgets.externalshell import pythonshell
             if isinstance(shell, pythonshell.ExtPythonShellWidget):
                 shell = shell.parent()
-            self.variableexplorer.set_shellwidget(shell)
+            self.variableexplorer.set_shellwidget_from_id(id(shell))
         else:
+            # Checking if any IPython frontend has focus
             widget = QApplication.focusWidget()
             for ipf in self.ipython_frontends:
                 if widget is ipf or widget is ipf.get_focus_widget():
-                    if ipf.kernel_widget is not None:
-                        self.variableexplorer.set_shellwidget(
-                        ipf.kernel_widget)
+                    kwid = ipf.kernel_widget_id
+                    if kwid is not None:
+                        idx = self.extconsole.get_shell_index_from_id(kwid)
+                        if idx is not None:
+                            kw = self.extconsole.shellwidgets[idx]
+                            if self.inspector is not None:
+                                self.inspector.set_shell(kw)
+                            self.variableexplorer.set_shellwidget_from_id(kwid)
+                            
+                            # Setting the kernel widget as current widget for 
+                            # the external console's tabwidget: this is 
+                            # necessary for the editor/console link to be 
+                            # working (otherwise, features like "Execute in 
+                            # current interpreter" will not work with IPython 
+                            # clients unless the associated IPython kernel has 
+                            # been selected in the external console... that's 
+                            # not brilliant, but it works for now: we shall 
+                            # take action on this later
+                            self.extconsole.tabwidget.setCurrentWidget(kw)
+                            ipf.get_focus_widget().setFocus()
         
     def update_file_menu(self):
         """Update file menu"""
         self.load_temp_session_action.setEnabled(osp.isfile(TEMP_SESSION_PATH))
         
-    def __focus_widget_properties(self):
-        """Get properties of focus widget
-        Returns tuple (widget, properties) where properties is a tuple of
-        booleans: (is_console, not_readonly, readwrite_editor)"""
-        widget = QApplication.focusWidget()
-        from spyderlib.widgets.shell import ShellBaseWidget
-        from spyderlib.widgets.editor import TextEditBaseWidget
-        textedit_properties = None
-        if isinstance(widget, (ShellBaseWidget, TextEditBaseWidget)):
-            console = isinstance(widget, ShellBaseWidget)
-            not_readonly = not widget.isReadOnly()
-            readwrite_editor = not_readonly and not console
-            textedit_properties = (console, not_readonly, readwrite_editor)
-        return widget, textedit_properties
-        
     def update_edit_menu(self):
         """Update edit menu"""
         if self.menuBar().hasFocus():
@@ -1136,7 +1173,7 @@ class MainWindow(QMainWindow):
         for child in self.edit_menu.actions():
             child.setEnabled(False)        
         
-        widget, textedit_properties = self.__focus_widget_properties()
+        widget, textedit_properties = get_focus_widget_properties()
         if textedit_properties is None: # widget is not an editor/console
             return
         #!!! Below this line, widget is expected to be a QPlainTextEdit instance
@@ -1176,7 +1213,7 @@ class MainWindow(QMainWindow):
                       self.find_previous_action, self.replace_action]:
             child.setEnabled(False)
         
-        widget, textedit_properties = self.__focus_widget_properties()
+        widget, textedit_properties = get_focus_widget_properties()
         for action in self.editor.search_menu_actions:
             action.setEnabled(self.editor.isAncestorOf(widget))
         if textedit_properties is None: # widget is not an editor/console
@@ -1329,18 +1366,18 @@ class MainWindow(QMainWindow):
         actions = widget.toolbar_actions
         if actions is not None:
             add_actions(toolbar, actions)
-        
+
     def about(self):
         """About Spyder"""
         not_installed = _('(not installed)')
         try:
             from pyflakes import __version__ as pyflakes_version
         except ImportError:
-            pyflakes_version = not_installed
+            pyflakes_version = not_installed  # analysis:ignore
         try:
             from rope import VERSION as rope_version
         except ImportError:
-            rope_version = not_installed
+            rope_version = not_installed  # analysis:ignore
         import spyderlib.qt.QtCore
         qt_api = os.environ['QT_API']
         qt_lib = {'pyqt': 'PyQt4', 'pyside': 'PySide'}[qt_api]
@@ -1354,7 +1391,7 @@ class MainWindow(QMainWindow):
             _("About %s") % "Spyder",
             """<b>%s %s</b>
             <br>Scientific PYthon Development EnviRonment
-            <p>Copyright &copy; 2009-2011 Pierre Raybaut
+            <p>Copyright &copy; 2009-2012 Pierre Raybaut
             <br>Licensed under the terms of the MIT License
             <p>Created by Pierre Raybaut
             <br>Developed and maintained by the 
@@ -1530,9 +1567,10 @@ Please provide any additional information below.
         else:
             fname = file_uri(fname)
             start_file(fname)
-            
+
+    #---- IPython frontends management
     def new_ipython_frontend(self, connection_file=None,
-                             kernel_widget=None, kernel_name=None):
+                             kernel_widget_id=None):
         """Create a new IPython frontend"""
         cf = connection_file
         if cf is None:
@@ -1546,12 +1584,25 @@ Please provide any additional information below.
                     if cf.isdigit():
                         cf = 'kernel-%s.json' % cf
                     if re.match('^kernel-(\d+).json', cf):
-                        kernel_name = cf
                         break
                 else:
                     return
+
+        # Generating the kernel name
+        match = re.match('^kernel-(\d+).json', cf)
+        count = 0
+        while True:
+            kernel_name = match.groups()[0]+'/'+chr(65+count)
+            for ipf in self.ipython_frontends:
+                if ipf.kernel_name == kernel_name:
+                    break
+            else:
+                break
+            count += 1
+
+        # Creating the IPython plugin and associated dockwidget
         from spyderlib.plugins.ipython import IPythonPlugin
-        ipython_plugin = IPythonPlugin(self, cf, kernel_widget, kernel_name)
+        ipython_plugin = IPythonPlugin(self, cf, kernel_widget_id, kernel_name)
         try:
             ipython_plugin.register_plugin()
         except (IOError, UnboundLocalError):
@@ -1559,7 +1610,44 @@ Please provide any additional information below.
                                  _("Unable to connect to IPython kernel "
                                    "<b>`%s`") % cf)
             return
+    
+    def add_ipython_frontend(self, ipython_plugin):
+        """Add new IPython frontend to main window"""
+        self.add_dockwidget(ipython_plugin)
+
+        # Tabify the first frontend to the external console plugin, tabify 
+        # the next ones to the last created frontend:
+        if self.ipython_frontends:
+            other = self.ipython_frontends[-1]
+        else:
+            other= self.extconsole
+        self.tabifyDockWidget(other.dockwidget, ipython_plugin.dockwidget)
+        ipython_plugin.switch_to_plugin()
+
         self.ipython_frontends.append(ipython_plugin)
+
+    def remove_ipython_frontend(self, ipython_plugin):
+        """Remove IPython frontend from main window"""
+        self.ipython_frontends.remove(ipython_plugin)
+        self.removeDockWidget(ipython_plugin.dockwidget)
+        ipython_plugin.close()
+    
+    def close_related_ipython_frontends(self, ipython_plugin):
+        """Close all IPython frontends related to *connection_file*,
+        except the plugin *except_this_one*"""
+        for ipf in self.ipython_frontends[:]:
+            if ipf is not ipython_plugin and\
+               ipf.connection_file == ipython_plugin.connection_file:
+                self.remove_ipython_frontend(ipf)
+    
+    def get_ipython_widget(self, kernel_widget_id):
+        """Return IPython widget (ipython_plugin.ipython_widget) 
+        associated to kernel_widget_id"""
+        for ipf in self.ipython_frontends:
+            if ipf.kernel_widget_id == kernel_widget_id:
+                return ipf.ipython_widget
+        else:
+            raise ValueError, "Unknown kernel widget ID %r" % kernel_widget_id
         
     #---- PYTHONPATH management, etc.
     def get_spyder_pythonpath(self):
@@ -1591,9 +1679,7 @@ Please provide any additional information below.
         
     def update_modules(self):
         """Update module names list"""
-        from spyderlib.utils.external.pickleshare import PickleShareDB
-        db = PickleShareDB(MODULES_PATH)
-        del db['rootmodules']
+        del modules_db['rootmodules']
         
     def pythonpath_changed(self):
         """Project Explorer PYTHONPATH contribution has changed"""
@@ -1754,7 +1840,7 @@ def initialize():
     class FakeQApplication(QApplication):
         """Spyder's fake QApplication"""
         def __init__(self, args):
-            self = app
+            self = app  # analysis:ignore
         @staticmethod
         def exec_():
             """Do nothing because the Qt mainloop is already running"""
@@ -1918,8 +2004,6 @@ def main():
         mainwindow = None
         try:
             mainwindow = run_spyder(app, options)
-            if not osp.isfile(get_conf_path('db/rootmodules')):
-                getRootModules()
         except BaseException:
             CONF.set('main', 'crash', True)
             import traceback
