@@ -702,7 +702,8 @@ class BaseTableView(QTableView):
             condition_imshow = condition_plot and self.get_array_ndim(key) == 2
             condition_imshow = condition_imshow or self.is_image(key)
         else:
-            is_array = condition_plot = condition_imshow = is_list = False
+            is_array = condition_plot = condition_imshow = is_list \
+                     = condition_hist = False
         self.plot_action.setVisible(condition_plot or is_list)
         self.hist_action.setVisible(condition_hist or is_list)
         self.imshow_action.setVisible(condition_imshow)
