@@ -64,11 +64,6 @@ def listdir(path, include='.', exclude=r'\.pyc$|^\.', show_all=False,
            sorted(namelist, key=unicode.lower)
 
 
-def abspardir(path):
-    """Return absolute parent dir"""
-    return osp.abspath(osp.join(path, os.pardir))
-
-
 def has_subdirectories(path, include, exclude, show_all):
     """Return True if path has subdirectories"""
     try:
@@ -291,7 +286,7 @@ class DirView(QTreeView):
                                triggered=lambda fnames=fnames:
                                self.open_interpreter(fnames))
         actions.append(action)
-        if programs.is_module_installed('IPython', '0.1'):
+        if programs.is_module_installed('IPython', '0.10'):
             _title = _("Open IPython here")
             action = create_action(self, _title, icon="ipython.png",
                                    triggered=lambda fnames=fnames:
