@@ -696,10 +696,6 @@ class PythonShellWidget(ShellBaseWidget):
         self.inspector = None
         self.inspector_enabled = True
         
-        # Allow raw_input support:
-        self.input_loop = None
-        self.input_mode = False
-        
         # Mouse cursor
         self.__cursor_changed = False
 
@@ -734,7 +730,7 @@ class PythonShellWidget(ShellBaseWidget):
                                      tip=_("Clear line"),
                                      triggered=self.clear_line)
         clear_action = create_action(self, _("Clear shell"),
-                                     QKeySequence("Ctrl+Shift+Escape"),
+                                     QKeySequence("Ctrl+L"),
                                      icon=get_icon('clear.png'),
                                      tip=_("Clear shell contents "
                                            "('cls' command)"),
