@@ -12,7 +12,8 @@ from spyderlib.qt.QtCore import Qt, SIGNAL, SLOT
 from spyderlib.qt.QtGui import QVBoxLayout, QTextEdit, QDialog, QDialogButtonBox
 
 # Local import
-from spyderlib.config import get_icon, get_font, _
+from spyderlib.baseconfig import _
+from spyderlib.config import get_icon, get_font
 
 
 class TextEditor(QDialog):
@@ -21,6 +22,14 @@ class TextEditor(QDialog):
                  readonly=False, size=(400, 300)):
         QDialog.__init__(self, parent)
         
+        # Destroying the C++ object right after closing the dialog box,
+        # otherwise it may be garbage-collected in another QThread
+        # (e.g. the editor's analysis thread in Spyder), thus leading to
+        # a segmentation fault on UNIX or an application crash on Windows
+        self.setAttribute(Qt.WA_DeleteOnClose)
+        
+        self.text = None
+        
         self._conv = str if isinstance(text, str) else unicode
         
         self.layout = QVBoxLayout()
@@ -28,6 +37,7 @@ class TextEditor(QDialog):
 
         # Text edit
         self.edit = QTextEdit(parent)
+        self.connect(self.edit, SIGNAL('textChanged()'), self.text_changed)
         self.edit.setReadOnly(readonly)
         self.edit.setPlainText(text)
         if font is None:
@@ -51,23 +61,28 @@ class TextEditor(QDialog):
         self.setWindowTitle(_("Text editor") + \
                             "%s" % (" - "+str(title) if str(title) else ""))
         self.resize(size[0], size[1])
+    
+    def text_changed(self):
+        """Text has changed"""
+        self.text = self._conv(self.edit.toPlainText())
         
     def get_value(self):
         """Return modified text"""
-        return self._conv(self.edit.toPlainText())
+        # It is import to avoid accessing Qt C++ object as it has probably
+        # already been destroyed, due to the Qt.WA_DeleteOnClose attribute
+        return self.text
     
     
 def test():
     """Text editor demo"""
     from spyderlib.utils.qthelpers import qapplication
-    app = qapplication()
+    _app = qapplication()
     dialog = TextEditor("""
     01234567890123456789012345678901234567890123456789012345678901234567890123456789
     dedekdh elkd ezd ekjd lekdj elkdfjelfjk e
     """)
     dialog.show()
-    app.exec_()
-    if dialog.result():
+    if dialog.exec_():
         text = dialog.get_value()
         print "Accepted:", text
         dialog = TextEditor(text)
